@@ -270,6 +270,7 @@ ResourceTypeType = Literal["AutoScalingGroup", "EbsVolume", "Ec2Instance", "Lamb
 StatusType = Literal["Active", "Failed", "Inactive", "Pending"]
 ServiceName = Literal[
     "accessanalyzer",
+    "account",
     "acm",
     "acm-pca",
     "alexaforbusiness",
@@ -302,6 +303,7 @@ ServiceName = Literal[
     "chime-sdk-identity",
     "chime-sdk-messaging",
     "cloud9",
+    "cloudcontrol",
     "clouddirectory",
     "cloudformation",
     "cloudfront",
